@@ -66,7 +66,7 @@ use warnings FATAL => 'all';
 package HTML::Tested;
 use base 'Class::Accessor', 'Class::Data::Inheritable', 'Exporter';
 use Carp;
-our $VERSION = 0.27;
+our $VERSION = 0.28;
 
 our @EXPORT_OK = qw(HT HTV);
 
@@ -74,7 +74,6 @@ use constant HT => 'HTML::Tested';
 use constant HTV => 'HTML::Tested::Value';
 
 __PACKAGE__->mk_classdata('Widgets_List', []);
-__PACKAGE__->mk_classdata('Is_Seal_Cache_Enabled');
 
 =head1 METHODS
 
@@ -110,13 +109,11 @@ C<stash> should be hash reference.
 =cut
 sub ht_render {
 	my ($self, $stash, $parent_name) = @_;
-	$HTML::Tested::Seal::Cache = {} if $self->Is_Seal_Cache_Enabled;
 	for my $v (@{ $self->Widgets_List }) {
 		my $n = $v->name;
 		my $id = $parent_name ? $parent_name . "__$n" : $n;
 		$v->render($self, $stash, $id);
 	}
-	$HTML::Tested::Seal::Cache = undef if $self->Is_Seal_Cache_Enabled;
 }
 
 =head2 ht_find_widget($widget_name)
@@ -237,9 +234,6 @@ sub ht_make_query_string {
 	} @widget_names);
 }
 
-sub ht_enable_seal_cache { shift()->Is_Seal_Cache_Enabled(1); }
-sub ht_disable_seal_cache { shift()->Is_Seal_Cache_Enabled(undef); }
-
 1;
 
 =head1 BUGS
