@@ -6,7 +6,8 @@ use base 'Exporter';
 use Data::Dumper;
 use Carp;
 
-our @EXPORT_OK = qw(Register_Widget_Tester);
+our @EXPORT_OK = qw(Register_Widget_Tester Stash_Mismatch
+	Ensure_Value_To_Check);
 
 sub Stash_Mismatch {
 	my ($n, $res, $v) = @_;
